@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Search YouTube
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use Moo;
 use strictures 2;
@@ -89,7 +89,7 @@ WebService::YTSearch - Search YouTube
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -124,9 +124,9 @@ The user agent.
 
 =head2 new
 
-  $w = WebService::YTSearch->new(%arguments);
+  $w = WebService::YTSearch->new(key => $key);
 
-Create a new C<WebService::YTSearch> object.
+Create a new C<WebService::YTSearch> object given an API B<key>.
 
 =head2 search
 
@@ -147,10 +147,14 @@ L<https://developers.google.com/youtube/v3/docs/search/list>
 
 L<Moo>
 
+L<Mojo::JSON>
+
 L<Mojo::UserAgent>
 
 L<Mojo::URL>
 
+L<Try::Tiny>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
